@@ -9,7 +9,7 @@
  */
 
 #include <sm/gen.h>
-SM_RCSID("@(#)$Id: main.c,v 8.64.2.10 2003/01/23 22:34:24 ca Exp $")
+SM_RCSID("@(#)$Id: main.c,v 8.79 2003/10/20 22:25:09 ca Exp $")
 
 #define _DEFINE	1
 #include "libmilter.h"
@@ -86,7 +86,7 @@ smfi_stop()
 }
 
 /*
-**  default values for some variables.
+**  Default values for some variables.
 **	Most of these can be changed with the functions below.
 */
 
@@ -95,27 +95,28 @@ static char *conn = NULL;
 static int timeout = MI_TIMEOUT;
 static int backlog = MI_SOMAXCONN;
 
-#if _FFR_SMFI_OPENSOCKET
 /*
 **  SMFI_OPENSOCKET -- try the socket setup to make sure we'll be
-**		able to start up
+**		       able to start up
 **
 **	Parameters:
-**		None.
+**		rmsocket -- if true, instructs libmilter to attempt
+**			to remove the socket before creating it;
+**			only applies for "local:" or "unix:" sockets
 **
 **	Return:
 **		MI_SUCCESS/MI_FAILURE
 */
 
 int
-smfi_opensocket()
+smfi_opensocket(rmsocket)
+	bool rmsocket;
 {
 	if (smfi == NULL || conn == NULL)
 		return MI_FAILURE;
 
-	return mi_opensocket(conn, backlog, dbg, smfi);
+	return mi_opensocket(conn, backlog, dbg, rmsocket, smfi);
 }
-#endif /* _FFR_SMFI_OPENSOCKET */
 
 /*
 **  SMFI_SETDBG -- set debug level.
@@ -236,6 +237,7 @@ smfi_main()
 	/* Startup the listener */
 	if (mi_listener(conn, dbg, smfi, timeout, backlog) != MI_SUCCESS)
 		r = MI_FAILURE;
+
 	return r;
 }
 
