@@ -13,7 +13,7 @@
 
 #include <sendmail.h>
 
-SM_RCSID("@(#)$Id: alias.c,v 8.214.2.2 2003/10/06 20:43:29 ca Exp $")
+SM_RCSID("@(#)$Id: alias.c,v 8.217 2003/07/28 17:47:18 ca Exp $")
 
 #define SEPARATOR ':'
 # define ALIAS_SPEC_SEPARATORS	" ,/:"
@@ -139,7 +139,7 @@ alias(a, sendq, aliaslevel, e)
 	if (tTd(27, 5))
 	{
 		sm_dprintf("alias: QS_EXPANDED ");
-		printaddr(a, false);
+		printaddr(sm_debug_file(), a, false);
 	}
 	a->q_state = QS_EXPANDED;
 
