@@ -10,7 +10,7 @@
  * the sendmail distribution.
  *
  *
- *	$Id: conf.h,v 8.566 2002/10/31 03:26:25 ca Exp $
+ *	$Id: conf.h,v 8.567 2004/07/23 20:45:01 gshapiro Exp $
  */
 
 /*
@@ -145,6 +145,16 @@ struct rusage;	/* forward declaration to get gcc to shut up in wait.h */
 # define DBMMODE	0640
 #endif /* ! DBMMODE */
 
+/*
+**  Value which means a uid or gid value should not change
+*/
+
+#ifndef NO_UID
+# define NO_UID		-1
+#endif /* ! NO_UID */
+#ifndef NO_GID
+# define NO_GID		-1
+#endif /* ! NO_GID */
 
 /**********************************************************************
 **  Compilation options.
