@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1998-2001 Sendmail, Inc. and its suppliers.
+ * Copyright (c) 1998-2003 Sendmail, Inc. and its suppliers.
  *	All rights reserved.
  * Copyright (c) 1983, 1995-1997 Eric P. Allman.  All rights reserved.
  * Copyright (c) 1988, 1993
@@ -14,9 +14,9 @@
 #include <sendmail.h>
 
 #if USERDB
-SM_RCSID("@(#)$Id: udb.c,v 8.153.4.4 2002/12/03 17:57:41 gshapiro Exp $ (with USERDB)")
+SM_RCSID("@(#)$Id: udb.c,v 8.160 2003/04/03 16:32:46 ca Exp $ (with USERDB)")
 #else /* USERDB */
-SM_RCSID("@(#)$Id: udb.c,v 8.153.4.4 2002/12/03 17:57:41 gshapiro Exp $ (without USERDB)")
+SM_RCSID("@(#)$Id: udb.c,v 8.160 2003/04/03 16:32:46 ca Exp $ (without USERDB)")
 #endif /* USERDB */
 
 #if USERDB
@@ -176,7 +176,7 @@ udbexpand(a, sendq, aliaslevel, e)
 	keylen = sm_strlcpyn(keybuf, sizeof keybuf, 2, user, ":maildrop");
 
 	/* if name is too long, assume it won't match */
-	if (keylen > sizeof keybuf)
+	if (keylen >= sizeof keybuf)
 		return EX_OK;
 
 	/* build actual database key */
@@ -334,7 +334,7 @@ udbexpand(a, sendq, aliaslevel, e)
 				if (tTd(28, 5))
 				{
 					sm_dprintf("udbexpand: QS_EXPANDED ");
-					printaddr(a, false);
+					printaddr(sm_debug_file(), a, false);
 				}
 				a->q_state = QS_EXPANDED;
 			}
@@ -474,7 +474,7 @@ udbexpand(a, sendq, aliaslevel, e)
 				if (tTd(28, 5))
 				{
 					sm_dprintf("udbexpand: QS_EXPANDED ");
-					printaddr(a, false);
+					printaddr(sm_debug_file(), a, false);
 				}
 				a->q_state = QS_EXPANDED;
 			}
@@ -525,7 +525,7 @@ udbexpand(a, sendq, aliaslevel, e)
 				if (tTd(28, 5))
 				{
 					sm_dprintf("udbexpand: QS_EXPANDED ");
-					printaddr(a, false);
+					printaddr(sm_debug_file(), a, false);
 				}
 				a->q_state = QS_EXPANDED;
 			}
